Learn R Programming

rankdist (version 1.0.0)

DistancePair: Calculate Kendall distance between a pair of rankings #' Calculate Kendall distance matrix between a pair of rankings

Description

Calculate Kendall distance between a pair of rankings #' Calculate Kendall distance matrix between a pair of rankings

Usage

DistancePair(r1, r2)

Arguments

r1
a single ranking
r2
a single ranking

Value

  • Kendall distance value