Learn R Programming

rankdist (version 0.3.1)

MomentsEst: Find Initial Values of Fai

Description

MomentEst finds the initial values of fai which can be used in the subsequent optimization problems. Linear model is fitted to the log odds of rankings.

Usage

MomentsEst(dat, size, pi0 = NULL)

Arguments

dat
a RankData object
size
the number of samples to take in the linear model
pi0
an optional argument showing the location of central ranking. If not provided, Borda Count method is used to estimate the central ranking.

Value

  • estimated fai

Examples

Run this code
MomentsEst(apa_obj,40)

Run the code above in your browser using DataLab