DistancePair: Calculate Kendall distance between a pair of rankings
#' Calculate Kendall distance matrix between a pair of rankings
Description
Calculate Kendall distance between a pair of rankings
#' Calculate Kendall distance matrix between a pair of rankingsUsage
DistancePair(r1, r2)