Learn R Programming

rankdist (version 0.4.1)

rankdist-package: A package for fitting distance based ranking models

Description

The rankdist package implements distance based probability models for ranking data. Mixture models are also supported. Ranking data are stored as S4 objects to avoid confusions about representations.

Arguments

Details

ll{ Package: rankdist Type: Package Version: 0.3.1 Date: 2015-05-01 License: GPL (>= 2) } Distance based models are effective ways to model ranking data. This package supports models based on Kendall distance and weighted Kendall distance. Mixture models can be easily fitted as well. The package includes a well-studied ranking data set, the APA Election data.

References

Alvo, M., & Yu, Philip L.H. (2014), Statistical Methods for Ranking Data

Examples

Run this code
fitted_model <- RankDistanceModel(rankdata,rankinit,rankctrl)

Run the code above in your browser using DataLab